{ config, lib, pkgs, ... }:

with lib.my;
{
  imports = [
    ./hardware-configuration.nix
    ../server.nix
  ];

  networking.hostName = "pi";
  networking.hostId = "";

  hardware = {
    raspberry-pi."4" = {
      apply-overlays-dtmerge.enable = true;
      fkms-3d.enable = true;
    };
    deviceTree = {
      enable = true;
      filter = "*rpi-4-*.dtb";
    };
  };

  sound.enable = true;
  console.enable = false;

  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    systemWide = true;
  };

  services.shairport-sync = {
    enable = true;
    group = [ "pipewire" ];
    openFirewall = true;
  };

  services.zigbee2mqtt = {
    enable = true;
    settings = {
      homeassistant = true;
      frontend = true;
      permit_join = true;
    };
  };

  environment.systemPackages = with pkgs; [
    libraspberrypi
    raspberrypi-eeprom
  ];

  system.stateVersion = "22.11";
}

